@@ -11,10 +11,8 @@ PS_DESTROY_FUNC(redis);
 PS_GC_FUNC(redis);
 PS_CREATE_SID_FUNC(redis);
 
-#if (PHP_MAJOR_VERSION >= 7)
 PS_VALIDATE_SID_FUNC(redis);
 PS_UPDATE_TIMESTAMP_FUNC(redis);
-#endif
 
 PS_OPEN_FUNC(rediscluster);
 PS_CLOSE_FUNC(rediscluster);
@@ -22,6 +20,9 @@ PS_READ_FUNC(rediscluster);
 PS_WRITE_FUNC(rediscluster);
 PS_DESTROY_FUNC(rediscluster);
 PS_GC_FUNC(rediscluster);
+PS_CREATE_SID_FUNC(rediscluster);
+PS_VALIDATE_SID_FUNC(rediscluster);
+PS_UPDATE_TIMESTAMP_FUNC(rediscluster);
 
 #endif
 #endif
